@@ -2,11 +2,10 @@
 TODO:
   * Gør elev og lærer id til id men hvor at elev id har et S foran (Eks: S123456789) og lærer har et T foran (Eks: T12345678)
   * Fjern retry fra enkelte funktioner og gør det til en general ting
-  * Få lærere, elever, lokaler, osv. fra https://www.lectio.dk/lectio/681/FindSkemaAdv.aspx
 """
 
 from .imports import *
-from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær
+from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside
 
 class sdk:
     def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
@@ -65,4 +64,10 @@ class sdk:
         return _filer.fåFil(self, filUrl)
 
     def fravær(self):
-        return _fravær.fravær(self)
\ No newline at end of file
+        return _fravær.fravær(self)
+
+    def dokumenter(self, folderid=None):
+        return _dokumenter.dokumenter(self, folderid)
+
+    def forside(self):
+        return _forside.forside(self)
\ No newline at end of file
